@@ -3,7 +3,7 @@
 
 # PatchBay Canvas engine using QGraphicsView/Scene
 # Copyright (C) 2010-2019 Filipe Coelho <falktx@falktx.com>
-# Copyright (C) 2019-2024 Mathieu Picot <picotmathieu@gmail.com>
+# Copyright (C) 2019-2026 Mathieu Picot <picotmathieu@gmail.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -92,14 +92,10 @@ def patchbay_api(func: Callable):
 
 
 class CanvasObject(QObject):
-    port_added = Signal(int, int)
-    port_removed = Signal(int, int)
-    connection_added = Signal(int)
-    connection_removed = Signal(int)
     move_boxes_finished = Signal()
 
     def __init__(self, parent=None):
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         self._gps_to_join = set[int]()
         self.move_boxes_finished.connect(self._join_after_move)
 
@@ -219,13 +215,11 @@ def set_loading_items(yesno: bool, auto_redraw=False, prevent_overlap=True):
     
     if not yesno and auto_redraw:
         both_done = set[int]()
-        some_hidden = False
         boxes = list[BoxWidget]()
         
         for group_id in canvas.groups_to_redraw_out:
             group = canvas.get_group(group_id)
             if group is None:
-                some_hidden = True
                 continue
 
             for box in group.widgets:
@@ -234,8 +228,6 @@ def set_loading_items(yesno: bool, auto_redraw=False, prevent_overlap=True):
                     box.update_positions(scene_checks=False)
                     if box.isVisible():
                         boxes.append(box)
-                    else:
-                        some_hidden = True
                     
                     if port_mode & PortMode.INPUT:
                         both_done.add(group_id)
@@ -246,7 +238,6 @@ def set_loading_items(yesno: bool, auto_redraw=False, prevent_overlap=True):
             
             group = canvas.get_group(group_id)
             if group is None:
-                some_hidden = True
                 continue
 
             for box in group.widgets:
@@ -255,14 +246,12 @@ def set_loading_items(yesno: bool, auto_redraw=False, prevent_overlap=True):
                     box.update_positions(scene_checks=False)
                     if box.isVisible():
                         boxes.append(box)
-                    else:
-                        some_hidden = True
         
         if prevent_overlap:
             for box in boxes:
                 canvas.scene.deplace_boxes_from_repulsers([box])
         
-        if some_hidden:
+        if canvas.groups_to_redraw_out or canvas.groups_to_redraw_in:
             canvas.scene.resize_the_scene()
         canvas.scene.update()
     
@@ -893,8 +882,8 @@ def remove_port(group_id: int, port_id: int):
 
     del item
     canvas.remove_port(port)
+    GroupedLinesWidget.port_removed(port)
 
-    canvas.qobject.port_removed.emit(group_id, port_id)
     if canvas.loading_items:
         if port.port_mode is PortMode.OUTPUT:
             canvas.groups_to_redraw_out.add(group_id)
@@ -1084,7 +1073,6 @@ def connect_ports(connection_id: int, group_out_id: int, port_out_id: int,
 
     GroupedLinesWidget.prepare_conn_changes(group_out_id, group_in_id)
     canvas.qobject.connect_update_timer.start()
-    canvas.qobject.connection_added.emit(connection_id)
     
     if canvas.loading_items:
         return
@@ -1106,7 +1094,6 @@ def disconnect_ports(connection_id: int):
         tmp_conn.group_out_id, tmp_conn.group_in_id)
     
     canvas.qobject.connect_update_timer.start()
-    canvas.qobject.connection_removed.emit(connection_id)
 
     out_port = canvas.get_port(tmp_conn.group_out_id, tmp_conn.port_out_id)
     in_port = canvas.get_port(tmp_conn.group_in_id, tmp_conn.port_in_id)
